@@ -25,6 +25,9 @@ PCNPDNItem
 FactoryBaikeItem
 原厂价格
 EbusinessPrice
+
+物料
+MaterialItem
 """
 
 # Define here the models for your scraped items
@@ -546,7 +549,8 @@ class DetailDataplatformItem(scrapy.Item):
     category_name = scrapy.Field()
     category_id = scrapy.Field()
     layout_design = scrapy.Field()
-    other_pdf_url = scrapy.Field()
+    other_pdf_url = scrapy.Field() # 其他规格书{"名称":"pdf链接"}
+    raw_other_pdf_url = scrapy.Field() # 其他规格书{"名称":"pdf链接"}
     spider_date = scrapy.Field()
     raw_id = scrapy.Field()
 
@@ -574,7 +578,8 @@ class DetailResouItem(scrapy.Item):
     category_name = scrapy.Field()
     category_id = scrapy.Field()
     layout_design = scrapy.Field()
-    other_pdf_url = scrapy.Field()
+    other_pdf_url = scrapy.Field() # 其他规格书{"名称":"pdf链接"}
+    raw_other_pdf_url = scrapy.Field() # 其他规格书{"名称":"pdf链接"}
     spider_time = scrapy.Field()
 
 
@@ -671,3 +676,43 @@ class SmdITEM(scrapy.Item):
     sources_url = scrapy.Field()
     create_user = scrapy.Field()
     status = scrapy.Field()
+
+# 物料
+class MaterialItem(scrapy.Item):
+    # eg.1: item = MaterialItem(table="ware_detail_dataplatform")
+    # eg.2: item = MaterialItem(table_add="_dataplatform")
+
+    def __init__(self, *args, **kwargs):
+        table_params = {'table': kwargs.get('table', self.table)} if not kwargs.get('table_add', '') \
+            else {'table': kwargs.get('table', self.table) + kwargs.get('table_add', '')}
+        self.__dict__.update(table_params)
+        self._values = {}
+        if args or kwargs and 'table' not in kwargs and 'table_add' not in kwargs: 
+            for k, v in dict(*args, **kwargs).items():
+                self[k] = v
+        super(MaterialItem, self).__init__()
+    table = 'ware_detail'
+    sources = scrapy.Field()  # 来源：oneyac-唯样，szlcsc-立创，datasheet5 (唯一索引字段)
+    url = scrapy.Field()  # 详情链接 <----
+    title = scrapy.Field()  # 型号  (唯一索引字段)
+    img_url = scrapy.Field()  # 图片链接,如果有多个会以 | 隔开  <----``
+    raw_img_url = scrapy.Field()  # 图片链接,如果有多个会以 | 隔开  <----
+    pdf_url = scrapy.Field()  # pdf链接,如果有多个会以 | 隔开  <----
+    raw_pdf_url = scrapy.Field()  # pdf链接,如果有多个会以 | 隔开  <----
+    category_name = scrapy.Field()  # 分类名称  <----
+    category_id = scrapy.Field()  # xcc分类id  <---- {原厂英文名}_{分类英文名或者拼音(不要留空格)} (唯一索引字段)
+    brand_name = scrapy.Field()  # 品牌名称 (唯一索引字段)
+    brand_id = scrapy.Field()  # xcc品牌id
+    descs = scrapy.Field()  # 描述 <----
+    packing = scrapy.Field()  # 封装 <---- (唯一索引字段)
+    list_json = scrapy.Field()  # 列表json <---- 参数数据json单层结构
+    all_json = scrapy.Field() # 列表页json + 详情页数据块组装 <---- 参数数据json双层结构 
+    update_time = scrapy.Field()  # 更新时间 <----
+    create_time = scrapy.Field()  # 创建时间 <----
+    creator = scrapy.Field()  # 创建人 <-----
+    other_pdf_url = scrapy.Field()  # 其他规格书{"名称":"pdf链接"}
+    raw_other_pdf_url = scrapy.Field()  # 其他规格书{"名称":"pdf链接"}
+    layout_design = scrapy.Field()  # 电路图
+    raw_layout_design = scrapy.Field()  # 电路图原链接
+    spider_flag = scrapy.Field()  # 是否有wiki 有则1
+    del_flag = scrapy.Field() # 删除标记 删除则1 (唯一索引字段)
\ No newline at end of file
