@@ -57,9 +57,6 @@ class MongodbPipeline(object):
             raise Exception("level type error")
         elif postItem.get("level", None):  # level :: int
             postItem["level"] = int(postItem["level"])
-        if postItem.get("list_json", None):  # list_json :: json
-            if isinstance(postItem["list_json"], dict):
-                postItem["list_json"] = json.dumps(dict(postItem["list_json"]))
         min_work_tp = postItem.get("min_work_tp", None)
         if isinstance(min_work_tp, str) and min_work_tp.strip() == "":
             postItem["min_work_tp"] = None
@@ -96,13 +93,18 @@ class MongodbPipeline(object):
             postItem["p_category_id"] = postItem["p_category_id"].strip()
         if postItem.get("p_category_name", None):  # p_category_name :: 去两端空格
             postItem["p_category_name"] = postItem["p_category_name"].strip()
-        if postItem.get("brand_id", None):  # brand_id :: int
-            postItem["brand_id"] = int(postItem["brand_id"])
-        if postItem.get("level", None):  # level :: int
-            postItem["level"] = int(postItem["level"])
         if postItem.get("list_json", None):  # list_json :: json
             if isinstance(postItem["list_json"], dict):
-                postItem["list_json"] = json.dumps(dict(postItem["list_json"]))
+                postItem["list_json"] = json.dumps(dict(postItem["list_json"]),ensure_ascii=False)
+        if postItem.get("all_json", None):  # all_json :: json
+            if isinstance(postItem["all_json"], dict):
+                postItem["all_json"] = json.dumps(dict(postItem["all_json"]),ensure_ascii=False)
+        if postItem.get("raw_other_pdf_url", None):  # raw_other_pdf_url :: json
+            if isinstance(postItem["raw_other_pdf_url"], dict):
+                postItem["raw_other_pdf_url"] = json.dumps(dict(postItem["raw_other_pdf_url"]),ensure_ascii=False)
+        if postItem.get("other_pdf_url", None):  # other_pdf_url :: json
+            if isinstance(postItem["other_pdf_url"], dict):
+                postItem["other_pdf_url"] = json.dumps(dict(postItem["other_pdf_url"]),ensure_ascii=False)
         if postItem.get('create_time', None):  # create_time标准时间格式2022-01-01 00:00:00
             postItem['create_time'] = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
         if postItem.get('spider_time', None):  # spider_time标准时间格式2022-01-01 00:00:00
