@@ -268,7 +268,7 @@ class OssFilesPipeline(MediaPipeline):
                     contents = requests.get(response.request.url,headers = headers, timeout=(10,120)).content
                     response = response.replace(body=contents)
                     logging.info(f"Retry {i+1} times , Url is {response.request.url}")
-                    if i+1 >= retry_invalid_times : return
+                    if i+1 >= retry_invalid_times : raise
                 
         media_ext_guss = os.path.splitext(os.path.basename(urlparse(request.url).path))[1]
 
@@ -277,7 +277,7 @@ class OssFilesPipeline(MediaPipeline):
                 valid = fitz.Document(stream=response.body, filetype="pdf")
             except Exception as e:
                 print(e)
-                return
+                raise
 
         if self.invalid_fild_paths:
             # invalid_fild_path <list> :: 失效文件路径,表示遇到该文件内容与invalid_fild_path路径下内容一致时返回空
@@ -327,16 +327,6 @@ class OssFilesPipeline(MediaPipeline):
             raise FileException(str(exc))
 
         return {'url': request.url, 'path': path, 'checksum': checksum, 'status': status}
-
-    def transf_img2_pdf(self,img_urls):
-        # if "png" in img_urls or "jpg" in img_urls:
-        stream_list = list()
-        for img in img_urls.split('|'):
-            stream_list.append(requests.get(img,timeout=10).content)
-        path = ".".join([img.rsplit(".",1)[0],"pdf"])
-        buf = io.BytesIO(img2pdf.convert(stream_list))
-        self.store.persist_file(path,buf,info=None)
-        return path
         
 
     def get_media_requests(self, item, info):
@@ -386,13 +376,8 @@ class OssFilesPipeline(MediaPipeline):
     def item_completed(self, results, item, info):
         if self.file_pipe_config.get(self.__class__.__name__,{}).get("RESOURCE_CLASSNAME",'').lower() in item.__class__.__name__.lower():
             with suppress(TypeError):
-                img_urls = '|'.join([x['path'] for ok, x in results if ok])
-                if img_urls :
-                    if "png" in img_urls or "jpeg" in img_urls :
-                        obj_path = self.transf_img2_pdf(img_urls)
-                        ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = obj_path
-                    else:
-                        ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = '|'.join([x['path'] for ok, x in results if ok])
+                if '|'.join([x['path'] for ok, x in results if ok and x['path']]):
+                    ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = '|'.join([x['path'] for ok, x in results if ok and x['path']])
             # TAG: 如果决定资源字段返回为空不存表,修改 FILTER_EMPTY_ITEM = True , 默认false
             with suppress(KeyError):
                 if not item.get(self.file_pipe_config.get(self.__class__.__name__,{}).get("FILES_OSS_RESULT_FIELD",''),"") and self.filter_empty_item:
@@ -436,7 +421,36 @@ class OssFilesPipeline(MediaPipeline):
         spider.crawler.stats.inc_value(f'file_status_count/{status}', spider=spider)
 
 
-class OssFilesPipelineDatasheet(OssFilesPipeline):
+class OssPDFPipeline(OssFilesPipeline):
+    def transf_img2_pdf(self,img_urls):
+        stream_list = list()
+        for img in img_urls.split('|'):
+            stream_list.append(requests.get(img,timeout=10).content)
+        path = ".".join([img.rsplit(".",1)[0],"pdf"])
+        buf = io.BytesIO(img2pdf.convert(stream_list))
+        self.store.persist_file(path,buf,info=None)
+        return path
+
+    def item_completed(self, results, item, info):
+        if self.file_pipe_config.get(self.__class__.__name__,{}).get("RESOURCE_CLASSNAME",'').lower() in item.__class__.__name__.lower():
+            with suppress(TypeError):
+                file_urls = '|'.join([x['path'] for ok, x in results if ok])
+                if file_urls :
+                    if "png" in file_urls or "jpeg" in file_urls :
+                        obj_path = self.transf_img2_pdf(file_urls)
+                        ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = obj_path
+                    else:
+                        ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__,{}).get('FILES_OSS_RESULT_FIELD',self.files_oss_result_field)] = '|'.join([x['path'] for ok, x in results if ok])
+            # TAG: 如果决定资源字段返回为空不存表,修改 FILTER_EMPTY_ITEM = True , 默认false
+            with suppress(KeyError):
+                if not item.get(self.file_pipe_config.get(self.__class__.__name__,{}).get("FILES_OSS_RESULT_FIELD",''),"") and self.filter_empty_item:
+                    if self.if_feed :# 解决输出文件时出现bug情况
+                        return {}
+                    else:
+                        raise DropItem()
+        return item
+
+class OssFilesPipelineDatasheet(OssPDFPipeline):
     
     def media_downloaded(self, response, request, info, *, item=None):  # 判断是否正常资源
         referer = referer_str(request)
@@ -500,9 +514,15 @@ class OssFilesPipelineDatasheet(OssFilesPipeline):
 
 
 
-class OssFilesPipelineBak(OssFilesPipeline): #备用文件储存类 如其他pdf
+class OssFilesPipelineBak(OssFilesPipeline): # 弃用
     pass
 
-class OssFilesPipelineBakBak(OssFilesPipeline): #备用文件储存类
+class OssFilesPipelineBakBak(OssFilesPipeline): #弃用
+    pass
+
+class OssPDFPipelineBak(OssPDFPipeline): # 备用文件储存类 如其他pdf
+    pass
+
+class OssPDFPipelineBakBak(OssPDFPipeline): #备用文件储存类
     pass
 
